==> open-xchange-documents-backend_7.8.0.orig.tar.bz2: open-xchange-documents-backend-7.8.0/com.openexchange.office.hazelcast.serialization/src/com/openexchange/office/hazelcast/serialization/osgi/HazelcastSerializationActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.hazelcast.serialization.osgi;

import com.openexchange.hazelcast.serialization.CustomPortableFactory;
import com.openexchange.office.hazelcast.serialization.document.PortableDocumentFactory;
import com.openexchange.office.hazelcast.serialization.document.PortableIDFactory;
import com.openexchange.osgi.HousekeepingActivator;


/**
 * {@link HazelcastSerializationActivator}
 *
 * @author <a href="mailto:carsten.driesner@open-xchange.com">Carsten Driesner</a>
 * @since 7.8.0
 */
public class HazelcastSerializationActivator extends HousekeepingActivator {

    @Override
    protected Class<?>[] getNeededServices() {
        return null;
    }

    @Override
    protected void startBundle() throws Exception {
        Services.setServiceLookup(this);
        registerService(CustomPortableFactory.class, new PortableDocumentFactory());
        registerService(CustomPortableFactory.class, new PortableIDFactory());
    }

    @Override
    protected void stopBundle() throws Exception {
        Services.setServiceLookup(null);
        super.stopBundle();
    }

}

==> open-xchange-documents-backend_7.8.1.orig.tar.bz2: open-xchange-documents-backend-7.8.1/com.openexchange.office.hazelcast.serialization/src/com/openexchange/office/hazelcast/serialization/osgi/HazelcastSerializationActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.hazelcast.serialization.osgi;

import com.openexchange.hazelcast.serialization.CustomPortableFactory;
import com.openexchange.office.hazelcast.serialization.document.PortableCleanupStatusFactory;
import com.openexchange.office.hazelcast.serialization.document.PortableDocSaveStateFactory;
import com.openexchange.office.hazelcast.serialization.document.PortableDocumentFactory;
import com.openexchange.office.hazelcast.serialization.document.PortableDocumentResourcesFactory;
import com.openexchange.office.hazelcast.serialization.document.PortableIDFactory;
import com.openexchange.office.hazelcast.serialization.document.PortableResourceIDFactory;
import com.openexchange.office.hazelcast.serialization.document.PortableRestoreIDFactory;
import com.openexchange.osgi.HousekeepingActivator;


/**
 * {@link HazelcastSerializationActivator}
 *
 * @author <a href="mailto:carsten.driesner@open-xchange.com">Carsten Driesner</a>
 * @since 7.8.0
 */
public class HazelcastSerializationActivator extends HousekeepingActivator {

    @Override
    protected Class<?>[] getNeededServices() {
        return null;
    }

    @Override
    protected void startBundle() throws Exception {
        Services.setServiceLookup(this);
        registerService(CustomPortableFactory.class, new PortableIDFactory());
        registerService(CustomPortableFactory.class, new PortableDocumentFactory());
        registerService(CustomPortableFactory.class, new PortableDocSaveStateFactory());
        registerService(CustomPortableFactory.class, new PortableDocumentResourcesFactory());
        registerService(CustomPortableFactory.class, new PortableResourceIDFactory());
        registerService(CustomPortableFactory.class, new PortableRestoreIDFactory());
        registerService(CustomPortableFactory.class, new PortableCleanupStatusFactory());
    }

    @Override
    protected void stopBundle() throws Exception {
        Services.setServiceLookup(null);
        super.stopBundle();
    }

}
